@@ -2,7 +2,7 @@
 #
 # The MIT License
 # 
-# Copyright (c) 2009-2010 Felix Schwarz <felix.schwarz@oss.schwarz.eu>
+# Copyright (c) 2009-2010, 2012 Felix Schwarz <felix.schwarz@oss.schwarz.eu>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,19 +23,29 @@
 # THE SOFTWARE.
 
 from pycerberus import InvalidDataError
-from pycerberus.lib import PythonicTestCase
+from pycerberus.lib.simple_super import SuperProxy
+from pycerberus.lib.pythonic_testcase import *
 
 
 class ValidationTest(PythonicTestCase):
     
+    super = SuperProxy()
+    # don't initialize '_validator' attribute in 'setUp()' so that subclasses
+    # can initialize the validator themself before calling this 'setUp()'.
+    # This is important if the validator to be tested requires mandatory 
+    # arguments for initialization.
+    _validator = None
+    
     def setUp(self):
         self.super()
-        self._validator = None
         if hasattr(self, 'validator_class'):
-            self.init_validator()
+            # this will set up the validator with the correct arguments 
+            # specified in the testcase
+            self.validator()
     
     def init_validator(self, validator=None, *args, **kwargs):
         if (validator is None) and hasattr(self, 'validator_class'):
+            # FIXME: This won't work as args filled means that validator != None
             validator = self.validator_class(*args, **kwargs)
         self._validator = validator
         return self._validator
@@ -45,7 +55,9 @@ class ValidationTest(PythonicTestCase):
         created yet)."""
         if self._validator is not None:
             return self._validator
-        return self.init_validator()
+        
+        args = [None] + list(getattr(self, 'validator_args', ()))
+        return self.init_validator(*args)
         
     schema = validator
     
@@ -54,9 +66,14 @@ class ValidationTest(PythonicTestCase):
             kwargs['context'] = {}
         return self._validator.process(*args, **kwargs)
     
+    def revert_conversion(self, *args, **kwargs):
+        if len(args) == 1 and 'context' not in kwargs:
+            kwargs['context'] = {}
+        return self._validator.revert_conversion(*args, **kwargs)
+    
     def assert_error(self, value, *args, **kwargs):
         call = lambda: self.process(value, *args, **kwargs)
-        return self.assert_raises(InvalidDataError, call)
+        return assert_raises(InvalidDataError, call)
     
     def assert_error_with_locale(self, value, locale='en', *args, **kwargs):
         """Process the given value and assert that this raises a validation
@@ -67,7 +84,6 @@ class ValidationTest(PythonicTestCase):
     
     def message_for_key(self, key, locale='de'):
         "Return the error message for the given key."
-        call = lambda: self.validator().error(key, None, {'locale': locale})
-        exception = self.assert_raises(InvalidDataError, call)
+        exception = self.validator().exception(key, None, {'locale': locale})
         return exception.details().msg()
 
