@@ -22,7 +22,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from pycerberus import InvalidDataError
+from pycerberus import InvalidArgumentsError, InvalidDataError
+from pycerberus.lib.pythonic_testcase import *
 from pycerberus.test_util import ValidationTest
 from pycerberus.validators import StringValidator
 
@@ -37,13 +38,13 @@ class StringValidatorTest(ValidationTest):
         self.assert_equals(u'bär', self.process(u'bär'))
     
     def test_reject_bad_types(self):
-        self.assert_raises(InvalidDataError, self.process, [])
-        self.assert_raises(InvalidDataError, self.process, {})
-        self.assert_raises(InvalidDataError, self.process, object)
-        self.assert_raises(InvalidDataError, self.process, 5)
+        assert_raises(InvalidDataError, lambda: self.process([]))
+        assert_raises(InvalidDataError, lambda: self.process({}))
+        assert_raises(InvalidDataError, lambda: self.process(object))
+        assert_raises(InvalidDataError, lambda: self.process(5))
     
     def test_show_class_name_in_error_message(self):
-        e = self.assert_raises(InvalidDataError, self.process, [])
+        e = self.assert_raises(InvalidDataError, lambda: self.process([]))
         self.assert_contains(u'(expected string, got "list")', e.details().msg())
     
     def test_empty_string_is_also_empty(self):
@@ -53,4 +54,39 @@ class StringValidatorTest(ValidationTest):
         self.init_validator(default='foo', required=False)
         self.assert_equals('foo', self.process(None))
         self.assert_equals('foo', self.process(''))
+    
+    def test_can_specify_min_length(self):
+        self.init_validator(StringValidator(min_length=3))
+        self.process('foo')
+        self.assert_error('fo')
+    
+    def test_can_specify_max_length(self):
+        self.init_validator(StringValidator(max_length=3))
+        self.process('foo')
+        self.assert_error('foobar')
+    
+    def test_can_specify_min_and_max_length_together(self):
+        self.init_validator(StringValidator(min_length=2, max_length=3))
+        self.assert_error('f')
+        self.process('fo')
+        self.process('foo')
+        self.assert_error('foobar')
+    
+    def test_min_length_must_be_smaller_or_equal_max_length(self):
+        assert_raises(InvalidArgumentsError, 
+            lambda: StringValidator(min_length=2, max_length=1))
+
+
+class ValidatorsDerivedFromStringTest(ValidationTest):
+    class TrueValidator(StringValidator):
+        def convert(self, value, context):
+            return True
+    
+    validator_class = TrueValidator
+    
+    def test_only_test_for_length_if_explicitely_set(self):
+        self.process('5')
+        
+        self.init_validator(self.validator_class(min_length=0))
+        assert_raises(TypeError, lambda: self.process('5'))
 
